# -*- coding: utf-8 -*-

"""
Tests for upraise.templating
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

:date: $Date: 2007-06-12 11:28:34 +0200 (Di, 12 Jun 2007) $
:revision: $Rev: 135 $
:copyright: 2006-2007 Jochen Kupperschmidt
:license: MIT, see LICENSE for details.
"""

from upraise.routing import RoutingMiddleware, url_for


def test_routing_middleware():
    def test(path, controller, action, id):
        def app(environ, start_response):
            positional_args, named_args = environ['wsgiorg.routing_args']
            assert positional_args == ()

            expected_named_args = dict(controller=controller, action=action)
            if id is not None:
                expected_named_args['id'] = id
            assert named_args == expected_named_args

            assert environ['SCRIPT_NAME'] == path
            assert environ['PATH_INFO'] == ''

        environ = dict(SCRIPT_NAME='', PATH_INFO=path)
        mw = RoutingMiddleware(app, 'home')
        mw(environ, None)

    test('/', 'home', 'index', None)
    test('/home', 'home', 'index', None)
    test('/news', 'news', 'index', None)
    test('/news/archive', 'news', 'archive', None)
    test('/news/view/42', 'news', 'view', '42')


def test_url_for():
    assert url_for(controller='') == '/'
    assert url_for(controller='news') == '/news'
    assert url_for(controller='news', action='index') == '/news'
    assert url_for(controller='news', action='archive') == '/news/archive'
    assert url_for(controller='news', action='view', id=42) == \
        '/news/view/42'

    # The order in which URL parameters will be appended depends on
    # ``urllib.urlencode`` and can not be predicted for sure.
    assert url_for(controller='news', action='view', id=42,
        group_by='month', sort='asc') in (
            '/news/view/42?group_by=month&sort=asc',
            '/news/view/42?sort=asc&group_by=month')
