# -*- coding: utf-8 -*-

"""
Upraise
~~~~~~~

Upraise is a thin web application framework.

It is based on WSGI (see :PEP:`333` for more information) and utilizes the
`Paste`_ library. This allows it to be deployed in various ways, including
CGI, `FastCGI`_, `SCGI`_, `mod_python`_ and as standalone HTTP server.

This is not a full-stack framework that requires specific external components
to be used with. Instead, any desired component should be easy to integrate
into Upraise, including template engines (e.g. `Genshi`_, `Mako`_, or
`Jinja`_), database abstraction layers/ORMs (e.g. `SQLAlchemy`_, `Elixir`_, or
`SQLObject`_), URL dispatchers (e.g. `Routes`_, `selector`_, or Upraise's own,
very simple dispatcher), authentication and authorization mechanisms (e.g.
`AuthKit`_, or `barrel`_), i18n toolkits or whatever other component one might
wish to make use of. Not to mention lots of WSGI middlewares that are
available, although spread over multiple packages and sometimes redundant.

Upraise provides a basic, flexible framework that does require some better
understanding of the components desired to be used, but comes without the
overhead and maybe unsatisfying preselection that full-stack frameworks like
`TurboGears`_, `Django`_ and, although to a lesser extent, `Pylons`_ imply.

.. _Paste:          http://www.pythonpaste.org/
.. _FastCGI:        http://www.fastcgi.com/
.. _SCGI:           http://python.ca/scgi/protocol.txt
.. _mod_python:     http://www.modpython.org/
.. _Genshi:         http://genshi.edgewall.org/
.. _Mako:           http://www.makotemplates.org/
.. _Jinja:          http://jinja.pocoo.org/
.. _SQLAlchemy:     http://www.sqlalchemy.org/
.. _Elixir:         http://elixir.ematia.de/
.. _SQLObject:      http://sqlobject.org/
.. _Routes:         http://routes.groovie.org/
.. _selector:       http://lukearno.com/projects/selector/
.. _AuthKit:        http://authkit.org/
.. _barrel:         http://lukearno.com/projects/barrel/
.. _TurboGears:     http://turbogears.org/
.. _Django:         http://www.djangoproject.com/
.. _Pylons:         http://pylonshq.com/

:date: $Date: 2007-07-21 00:22:40 +0200 (Sa, 21 Jul 2007) $
:revision: $Rev: 167 $
:copyright: 2006-2007 Jochen Kupperschmidt
:license: MIT, see LICENSE for details.
"""

from paste.wsgiwrappers import WSGIResponse as Response

from upraise.util import config, request


__author__ = 'Jochen Kupperschmidt <homework at nwsnet dot de>'
__docformat__ = 'restructuredtext'
__license__ = 'MIT <http://www.opensource.org/licenses/mit-license.php>'
__url__ = 'http://homework.nwsnet.de/'
__version__ = '0.2'

__all__ = ['config', 'request', 'Response']
